@@ -34,6 +34,8 @@
 #include <stdarg.h>
 #include <locale.h>
 
+#include <ft2build.h>
+#include FT_FREETYPE_H
 #include <freetype/ftoutln.h>
 
 #include <libgnomeprint/gnome-print-private.h>
@@ -537,34 +539,35 @@ gnome_font_face_find (const guchar *name)
 	}
 }
 
-/* fixme: Do some well-known substitutions here */
-
 GnomeFontFace *
 gnome_font_face_find_closest (const guchar *name)
 {
-	GnomeFontFace *face;
-	GPFontMap *map;
-
-	face = NULL;
-
-	map = gp_fontmap_get ();
+	GnomeFontFace *face = NULL;
 
 	if (name)
 		face = gnome_font_face_find (name);
 
-	if (!face && map->fonts) {
-		/* No face, no default, load whatever font is first */
-		GPFontEntry *e;
-		e = (GPFontEntry *) map->fonts->data;
-		if (e->face) {
-			gnome_font_face_ref (e->face);
-		} else {
-			gff_face_from_entry (e);
+	if (!face)
+		face = gnome_font_face_find ("Sans Regular");
+
+	if (!face) {
+		GPFontMap *map = gp_fontmap_get ();
+		if (map && map->fonts) {
+			/* No face, no default, load whatever font is first */
+			GPFontEntry *e;
+			e = (GPFontEntry *) map->fonts->data;
+			if (e->face) {
+				gnome_font_face_ref (e->face);
+			} else {
+				gff_face_from_entry (e);
+			}
+			face = e->face;
 		}
-		face = e->face;
+		
+		gp_fontmap_release (map);
 	}
 
-	gp_fontmap_release (map);
+	g_return_val_if_fail (face != NULL, NULL);
 
 	return face;
 }
@@ -1222,7 +1225,7 @@ gnome_font_face_ps_embed_t1 (GnomeFontPsObject *pso)
 	if (pso->encodedbytes == 1) {
 		gint glyph;
 		/* 8-bit vector */
-		gf_pso_sprintf (pso, "/%s findfont dup length dict begin\n", embeddedname);
+		gf_pso_sprintf (pso, "(%s) cvn findfont dup length dict begin\n", embeddedname);
 		gf_pso_sprintf (pso, "{1 index /FID ne {def} {pop pop} ifelse} forall\n");
 		gf_pso_sprintf (pso, "/Encoding [\n");
 		for (glyph = 0; glyph < 256; glyph++) {
@@ -1238,7 +1241,7 @@ gnome_font_face_ps_embed_t1 (GnomeFontPsObject *pso)
 			gf_pso_sprintf (pso, ((glyph & 0xf) == 0xf) ? "/%s\n" : "/%s ", c);
 		}
 		gf_pso_sprintf (pso, "] def currentdict end\n");
-		gf_pso_sprintf (pso, "/%s exch definefont pop\n", pso->encodedname);
+		gf_pso_sprintf (pso, "(%s) cvn exch definefont pop\n", pso->encodedname);
 	} else {
 		gint nfonts, nglyphs, i, j;
 		/* 16-bit vector */
@@ -1249,7 +1252,7 @@ gnome_font_face_ps_embed_t1 (GnomeFontPsObject *pso)
 		/* Common entries */
 		gf_pso_sprintf (pso, "/FontType 0 def\n");
 		gf_pso_sprintf (pso, "/FontMatrix [1 0 0 1 0 0] def\n");
-		gf_pso_sprintf (pso, "/FontName /%s-Glyph-Composite def\n", embeddedname);
+		gf_pso_sprintf (pso, "/FontName (%s-Glyph-Composite) cvn def\n", embeddedname);
 		gf_pso_sprintf (pso, "/LanguageLevel 2 def\n");
 
 		/* Type 0 entries */
@@ -1258,7 +1261,7 @@ gnome_font_face_ps_embed_t1 (GnomeFontPsObject *pso)
 		/* Bitch 'o' bitches */
 		gf_pso_sprintf (pso, "/FDepVector [\n");
 		for (i = 0; i < nfonts; i++) {
-			gf_pso_sprintf (pso, "/%s findfont dup length dict begin\n", embeddedname);
+			gf_pso_sprintf (pso, "(%s) cvn findfont dup length dict begin\n", embeddedname);
 			gf_pso_sprintf (pso, "{1 index /FID ne {def} {pop pop} ifelse} forall\n");
 			gf_pso_sprintf (pso, "/Encoding [\n");
 			for (j = 0; j < 256; j++) {
@@ -1276,7 +1279,7 @@ gnome_font_face_ps_embed_t1 (GnomeFontPsObject *pso)
 				gf_pso_sprintf (pso, ((j & 0xf) == 0xf) ? "/%s\n" : "/%s ", c);
 			}
 			gf_pso_sprintf (pso, "] def\n");
-			gf_pso_sprintf (pso, "currentdict end /%s-Glyph-Page-%d exch definefont\n", embeddedname, i);
+			gf_pso_sprintf (pso, "currentdict end (%s-Glyph-Page-%d) cvn exch definefont\n", embeddedname, i);
 		}
 		gf_pso_sprintf (pso, "] def\n");
 		gf_pso_sprintf (pso, "/Encoding [\n");
@@ -1287,7 +1290,7 @@ gnome_font_face_ps_embed_t1 (GnomeFontPsObject *pso)
 		}
 		gf_pso_sprintf (pso, "] def\n");
 		gf_pso_sprintf (pso, "currentdict end\n");
-		gf_pso_sprintf (pso, "/%s exch definefont pop\n", pso->encodedname);
+		gf_pso_sprintf (pso, "(%s) cvn exch definefont pop\n", pso->encodedname);
 	}
 }
 
@@ -1332,7 +1335,7 @@ gnome_font_face_ps_embed_tt (GnomeFontPsObject *pso)
 		MfrRevision = 1.0;
 		gf_pso_sprintf (pso, "%%!PS-TrueTypeFont-%g-%g\n", TTVersion, MfrRevision);
 		gf_pso_sprintf (pso, "11 dict begin\n");
-		gf_pso_sprintf (pso, "/FontName /%s def\n", embeddedname);
+		gf_pso_sprintf (pso, "/FontName (%s) cvn def\n", embeddedname);
 		gf_pso_sprintf (pso, "/Encoding 256 array\n");
 		gf_pso_sprintf (pso, "0 1 255 {1 index exch /.notdef put} for\n");
 		gf_pso_sprintf (pso, "readonly def\n");
@@ -1408,7 +1411,7 @@ gnome_font_face_ps_embed_tt (GnomeFontPsObject *pso)
 		gint glyph;
 		/* 8-bit vector */
 		pso->encodedbytes = 1;
-		gf_pso_sprintf (pso, "/%s findfont dup length dict begin\n", embeddedname);
+		gf_pso_sprintf (pso, "(%s) cvn findfont dup length dict begin\n", embeddedname);
 		gf_pso_sprintf (pso, "{1 index /FID ne {def} {pop pop} ifelse} forall\n");
 		gf_pso_sprintf (pso, "/Encoding [\n");
 		for (glyph = 0; glyph < 256; glyph++) {
@@ -1421,7 +1424,7 @@ gnome_font_face_ps_embed_tt (GnomeFontPsObject *pso)
 			}
 		}
 		gf_pso_sprintf (pso, "] def currentdict end\n");
-		gf_pso_sprintf (pso, "/%s exch definefont pop\n", pso->encodedname);
+		gf_pso_sprintf (pso, "(%s) cvn exch definefont pop\n", pso->encodedname);
 	} else {
 		gint nfonts, nglyphs, i, j;
 		/* 16-bit vector */
@@ -1433,14 +1436,14 @@ gnome_font_face_ps_embed_tt (GnomeFontPsObject *pso)
 		/* Common entries */
 		gf_pso_sprintf (pso, "/FontType 0 def\n");
 		gf_pso_sprintf (pso, "/FontMatrix [1 0 0 1 0 0] def\n");
-		gf_pso_sprintf (pso, "/FontName /%s-Glyph-Composite def\n", embeddedname);
+		gf_pso_sprintf (pso, "/FontName (%s-Glyph-Composite) cvn def\n", embeddedname);
 		gf_pso_sprintf (pso, "/LanguageLevel 2 def\n");
 		/* Type 0 entries */
 		gf_pso_sprintf (pso, "/FMapType 2 def\n");
 		/* Bitch 'o' bitches */
 		gf_pso_sprintf (pso, "/FDepVector [\n");
 		for (i = 0; i < nfonts; i++) {
-			gf_pso_sprintf (pso, "/%s findfont dup length dict begin\n", embeddedname);
+			gf_pso_sprintf (pso, "(%s) cvn findfont dup length dict begin\n", embeddedname);
 			gf_pso_sprintf (pso, "{1 index /FID ne {def} {pop pop} ifelse} forall\n");
 			gf_pso_sprintf (pso, "/Encoding [\n");
 			for (j = 0; j < 256; j++) {
@@ -1455,7 +1458,7 @@ gnome_font_face_ps_embed_tt (GnomeFontPsObject *pso)
 				}
 			}
 			gf_pso_sprintf (pso, "] def\n");
-			gf_pso_sprintf (pso, "currentdict end /%s-Glyph-Page-%d exch definefont\n", embeddedname, i);
+			gf_pso_sprintf (pso, "currentdict end (%s-Glyph-Page-%d) cvn exch definefont\n", embeddedname, i);
 		}
 		gf_pso_sprintf (pso, "] def\n");
 		gf_pso_sprintf (pso, "/Encoding [\n");
@@ -1466,7 +1469,7 @@ gnome_font_face_ps_embed_tt (GnomeFontPsObject *pso)
 		}
 		gf_pso_sprintf (pso, "] def\n");
 		gf_pso_sprintf (pso, "currentdict end\n");
-		gf_pso_sprintf (pso, "/%s exch definefont pop\n", pso->encodedname);
+		gf_pso_sprintf (pso, "(%s) cvn exch definefont pop\n", pso->encodedname);
 	}
 }
 
@@ -1494,16 +1497,16 @@ gnome_font_face_ps_embed_empty (GnomeFontPsObject *pso)
 	gf_pso_sprintf (pso, "/BuildChar {1 index /Encoding get exch get 1 index /BuildGlyph get exec } bind def\n");
 	if (pso->encodedbytes == 1) {
 		/* 8-bit empty font */
-		gf_pso_sprintf (pso, "currentdict end /%s exch definefont pop\n", pso->encodedname);
+		gf_pso_sprintf (pso, "currentdict end (%s) cvn exch definefont pop\n", pso->encodedname);
 	} else {
 		/* 16-bit empty font */
-		gf_pso_sprintf (pso, "currentdict end /%s-Base exch definefont pop\n", pso->encodedname);
+		gf_pso_sprintf (pso, "currentdict end (%s-Base) cvn exch definefont pop\n", pso->encodedname);
 		gf_pso_sprintf (pso, "32 dict begin /FontType 0 def /FontMatrix [1 0 0 1 0 0] def\n");
-		gf_pso_sprintf (pso, "/FontName /%s-Glyph-Composite def\n", pso->encodedname);
+		gf_pso_sprintf (pso, "/FontName (%s-Glyph-Composite) cvn def\n", pso->encodedname);
 		gf_pso_sprintf (pso, "/LanguageLevel 2 def /FMapType 2 def\n");
-		gf_pso_sprintf (pso, "/FDepVector [/%s-Base findfont] def", pso->encodedname);
+		gf_pso_sprintf (pso, "/FDepVector [(%s-Base) cvn findfont] def", pso->encodedname);
 		gf_pso_sprintf (pso, "/Encoding 256 array def 0 1 255 {Encoding exch 0 put} for\n");
-		gf_pso_sprintf (pso, "currentdict end /%s exch definefont pop\n", pso->encodedname);
+		gf_pso_sprintf (pso, "currentdict end (%s) cvn exch definefont pop\n", pso->encodedname);
 	}
 }
 
