@@ -285,19 +285,11 @@ gnome_font_find_closest (const guchar *name, gdouble size)
 	GnomeFontFace *face;
 	GnomeFont *font;
 
-	if (name)
-		face = gnome_font_face_find (name);
-	else
-		face = NULL;
+	face = gnome_font_face_find (name);
 
-	if (!face) {
-		/* fixme: */
-		face = gnome_font_face_find_closest ("Helvetica");
-		g_return_val_if_fail (face != NULL, NULL);
-	}
+	g_return_val_if_fail (face != NULL, NULL);
 
 	font = gnome_font_face_get_font_full (face, size, NULL);
-
 	gnome_font_face_unref (face);
 
 	return font;
