@@ -65,6 +65,13 @@ struct _JOBPrivate {
 	GList *LY_LIST;
 };
 
+enum
+{
+  PROP_0,
+  PROP_CONFIG,
+};
+ 
+
 #define GNOME_PRINT_JOB_CLOSED(m) (((JOBPrivate *) (m)->priv)->closed)
 
 static void gnome_print_job_class_init (GnomePrintJobClass *klass);
@@ -76,8 +83,18 @@ static void job_parse_config_data (GnomePrintJob *job);
 static void job_clear_config_data (GnomePrintJob *job);
 static gboolean job_parse_transform (guchar *str, gdouble *transform);
 
+static void gnome_print_job_get_property (GObject      *object,
+                                          guint         prop_id,
+                                          GValue       *value,
+                                          GParamSpec   *pspec);
+static void gnome_print_job_set_property (GObject      *object,
+                                          guint         prop_id,
+                                          const GValue *value,
+                                          GParamSpec   *pspec);
+
 static GObjectClass *parent_class;
 
+
 GType
 gnome_print_job_get_type (void)
 {
@@ -103,6 +120,18 @@ gnome_print_job_class_init (GnomePrintJobClass *klass)
 	GObjectClass *object_class;
 	
 	object_class = (GObjectClass *) klass;
+
+	object_class->set_property = gnome_print_job_set_property;
+	object_class->get_property = gnome_print_job_get_property;
+
+	g_object_class_install_property (object_class,
+                                   PROP_CONFIG,
+                                   g_param_spec_object ("config",
+                                                        "Job Configuration",
+                                                        "The configuration for the print job",
+                                                        GNOME_TYPE_PRINT_CONFIG,
+                                                        G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+  
 	parent_class = g_type_class_peek_parent (klass);
 
 	object_class->finalize = gnome_print_job_finalize;
@@ -150,6 +179,55 @@ gnome_print_job_finalize (GObject *object)
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
+static void
+gnome_print_job_get_property (GObject *object, guint prop_id, GValue *value,
+	                     GParamSpec *pspec)
+{
+  GnomePrintJob *job = GNOME_PRINT_JOB (object);
+
+  switch (prop_id)
+    {
+    case PROP_CONFIG:
+      g_value_set_object (value, gnome_print_job_get_config (job));
+      break;
+  
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      break;
+    }
+}
+
+static void
+gnome_print_job_set_property (GObject * object, guint prop_id,
+	                     const GValue * value, GParamSpec * pspec)
+{
+  GnomePrintJob *job = GNOME_PRINT_JOB (object);
+  GnomePrintConfig *config = NULL;
+
+  switch (prop_id)
+    {
+    case PROP_CONFIG:
+	    config = GNOME_PRINT_CONFIG (g_value_get_object (value));
+	    if (job->config) {
+		    gnome_print_config_unref (job->config);
+		    job->config = NULL;
+	    }
+	    
+	    if(config) {
+		    gnome_print_config_ref (config);
+		    job->config = config;
+	    } else {
+		    /* Use the default: */
+		    job->config = gnome_print_config_default ();
+	    }
+	    break;
+    default:
+	    G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+	    break;
+    }
+}
+
+
 /**
  * gnome_print_job_new:
  * @config: The job options, can be NULL in which case a
@@ -164,12 +242,7 @@ gnome_print_job_new (GnomePrintConfig *config)
 {
 	GnomePrintJob *job;
 	
-	job = g_object_new (GNOME_TYPE_PRINT_JOB, NULL);
-
-	if (config)
-		job->config = gnome_print_config_ref (config);
-	else
-		job->config = gnome_print_config_default ();
+	job = g_object_new (GNOME_TYPE_PRINT_JOB, "config", config, NULL);
 
 	return job;
 }
@@ -200,6 +273,8 @@ gnome_print_job_get_config (GnomePrintJob *job)
  * 
  * Retrieve the GnomePrintContext which applications
  * print to.
+ *
+ * The caller is responsible to unref the context when s/he is done with it.
  * 
  * Return value: The printing context, NULL on error
  **/
@@ -210,7 +285,7 @@ gnome_print_job_get_context (GnomePrintJob *job)
 	g_return_val_if_fail (GNOME_IS_PRINT_JOB (job), NULL);
 	g_return_val_if_fail (job->input_file == NULL, NULL);
 
-	if (!job->meta)
+	if (job->meta == NULL)
 		job->meta = gnome_print_meta_new ();
 
 	g_object_ref (G_OBJECT (job->meta));
