@@ -573,7 +573,7 @@ gnome_print_ps2_showpage (GnomePrintContext *pc)
 	while (ps2->pages->usedfonts) {
 		GnomePrintPs2Font *font;
 		font = ps2->pages->usedfonts->data;
-		ret += gnome_print_ps2_fprintf (ps2, "%%%%+ font %s" EOL, font->pso->encodedname);
+		ret += gnome_print_ps2_fprintf (ps2, "%%%%+ font (%s) cvn" EOL, font->pso->encodedname);
 		ps2->pages->usedfonts = g_slist_remove (ps2->pages->usedfonts, ps2->pages->usedfonts->data);
 	}
 
@@ -647,7 +647,7 @@ gnome_print_ps2_close (GnomePrintContext *pc)
 	gnome_print_transport_printf (pc->transport, "%%%%DocumentSuppliedResources: procset pnome-print-procs-%s" EOL, VERSION);
 	/* %%DocumentSuppliedResources: */
 	for (font = ps2->fonts; font != NULL; font = font->next) {
-		gnome_print_transport_printf (pc->transport, "%%%%+ font %s" EOL, font->pso->encodedname);
+		gnome_print_transport_printf (pc->transport, "%%%%+ font (%s) cvn" EOL, font->pso->encodedname);
 	}
 	gnome_print_transport_printf (pc->transport, "%%%%EndComments" EOL);
 	g_free (date);
@@ -683,7 +683,7 @@ gnome_print_ps2_close (GnomePrintContext *pc)
 	/* Download fonts */
 	for (font = ps2->fonts; font != NULL; font = font->next) {
 		gnome_font_face_ps_embed (font->pso);
-		gnome_print_transport_printf (pc->transport, "%%%%BeginResource: font %s" EOL, font->pso->encodedname);
+		gnome_print_transport_printf (pc->transport, "%%%%BeginResource: font (%s) cvn" EOL, font->pso->encodedname);
 		gnome_print_transport_write (pc->transport, font->pso->buf, font->pso->length);
 		gnome_print_transport_printf (pc->transport, "%%%%EndResource" EOL);
 	}
@@ -857,7 +857,7 @@ gnome_print_ps2_set_font_real (GnomePrintPs2 *ps2, const GnomeFont *gnome_font)
 		ps2->pages->usedfonts = g_slist_prepend (ps2->pages->usedfonts, font);
 	}
 
-	ret += gnome_print_ps2_fprintf (ps2, "/%s FF %g F" EOL, font->pso->encodedname, gnome_font_get_size (gnome_font));
+	ret += gnome_print_ps2_fprintf (ps2, "(%s) cvn FF %g F" EOL, font->pso->encodedname, gnome_font_get_size (gnome_font));
 
 	font->currentsize = gnome_font->size;
 	ps2->selected_font = font;
