@@ -251,11 +251,15 @@ gpa_node_lookup (GPANode *node, const guchar *path)
 		node = GPA_NODE (gpa_root);
 	}
 
+	g_return_val_if_fail (GPA_IS_NODE(node), NULL);
+
 	if (GPA_IS_REFERENCE (node)) {
 		node = GPA_REFERENCE_REFERENCE (node);
 	}
 
-	g_return_val_if_fail (node != NULL, NULL);
+	if (node == NULL)
+		return NULL;
+
 	g_return_val_if_fail (GPA_IS_NODE (node), NULL);
 
 	p = g_strdup (path);
